/*
******************************************************************************
*
*      File             : oacs-900.h
*      Version          : 9.0.0, 11. December 2009, Paolo Usai
*      Version          : 8.1.0, 27. March 2009, Karl Hellwig
*                         functional identical to version 6.3.0
*      Version          : 7.0.0, 14. June 2007, Paolo Usai
*      Version          : 6.4.0, 05. June 2007, Karl Hellwig
*      Version          : 6.3.0, 02. October 2006, Karl Hellwig
*      Version          : 6.2.0, 30. August 2005, Karl Hellwig
*      Version          : 2.2.0, 27. November 2000, Jochen Junkawitsch
*      Description      : header file for OACS selection rules
*
*
******************************************************************************
*/

#ifndef OACS_H_INCLUDED
#define OACS_H_INCLUDED



typedef unsigned char CodecSet;

typedef enum
{
  HR_AMR,
  FR_AMR,
  UMTS_AMR,
  UMTS_AMR_2,
  OHR_AMR,	//Karl Hellwig 2005-02-06
  FR_AMR_WB,	//Karl Hellwig 2005-02-16
  OHR_AMR_WB,	//Karl Hellwig 2005-02-16
  OFR_AMR_WB,	//Karl Hellwig 2005-02-16
  UMTS_AMR_WB,	//Karl Hellwig 2005-02-16
  GSM_EFR,
  GSM_FR,
  GSM_HR
} CodecType;


typedef enum
{
  mode_475 = 1,
  mode_515 = 2,
  mode_590 = 4,
  mode_670 = 8,
  mode_740 = 16,
  mode_795 = 32,
  mode_102 = 64,
  mode_122 = 128
} CodecMode;


  
/* ----------------------------------------------------------------------------------
                                     functions
   ---------------------------------------------------------------------------------- */


CodecSet calc_OACS(CodecSet aCscs, int cmacs, CodecType codecType);
/*
   Calculate the OACS.
   Input parameters:
     - CodecSet aCscs     : common supported codec set (CSCS)
     - int cmacs          : CMACS
     - CodecType codecType: HR_AMR if HR_AMR is involved, else FR_AMR
   Return value: OACS (type CodecSet)
*/



int nModes(CodecSet codecSet);
/*
   Return the number of modes in the codecSet.
*/

int highModeRule(CodecSet lacs, CodecSet dacs, CodecSet oacs);
int lowModeRule (CodecSet lacs, CodecSet dacs, CodecSet oacs, CodecType codecType);


#endif

